INSERT INTO crams_softwarelicensestatus(code, status) VALUES ('R', 'Submit');
INSERT INTO crams_softwarelicensestatus(code, status) VALUES ('A', 'Approve');
INSERT INTO crams_softwarelicensestatus(code, status) VALUES ('D', 'Decline');